@@ -1,6 +1,6 @@
 /**
 >HEADER
-    Copyright (c) 2014, 2015 Rob Patro robp@cs.stonybrook.edu
+    Copyright (c) 2014, 2015, 2016, 2017 Rob Patro robp@cs.stonybrook.edu
 
     This file is part of Salmon.
 
@@ -19,18 +19,18 @@
 <HEADER
 **/
 
-
 #ifndef SALMON_CONFIG_HPP
 #define SALMON_CONFIG_HPP
 
 #include <string>
 
 namespace salmon {
-	constexpr char majorVersion[] = "0";
-	constexpr char minorVersion[] = "7";
-	constexpr char patchVersion[] = "2";
-	constexpr char version[] = "0.7.2";
-    constexpr uint32_t indexVersion = 2;
-}
+constexpr char majorVersion[] = "0";
+constexpr char minorVersion[] = "12";
+constexpr char patchVersion[] = "0";
+constexpr char version[] = "0.12.0";
+constexpr uint32_t indexVersion = 2;
+constexpr char requiredQuasiIndexVersion[] = "q5";
+} // namespace salmon
 
 #endif // SALMON_CONFIG_HPP
